@@ -17,7 +17,7 @@ from Trainer import Trainer
 from network import ensure_dir
 
 
-def start(job_id, dataset_id=None, server_id='local', insights=False):
+def start(job_id, dataset_id=None, server_id='local', insights=False, insights_sample_path=None):
     """
     Starts the training process with all logging of a job_id
     """
@@ -25,23 +25,20 @@ def start(job_id, dataset_id=None, server_id='local', insights=False):
     aetros_backend = AetrosBackend(job_id)
 
     if '/' in job_id:
-        print("create job for %s ..." % (job_id,))
-        response = aetros_backend.create_job(job_id, server_id=server_id, dataset_id=dataset_id, insights=insights)
-        if response.status_code != 200:
-            print("Could not create job: %s " % (response.content,))
+        print("...")
+        job_id = aetros_backend.create_job(job_id, server_id=server_id, dataset_id=dataset_id, insights=insights)
+        if job_id is None:
             exit(1)
 
-        job_id = response.json()
-        print("Training '%d' created and started. Open http://%d/trainer/app?training=%d to monitor the training." %
+        print("Training '%s' created and started. Open http://%s/trainer/app?training=%s to monitor the training." %
               (job_id, aetros_backend.host, job_id))
     else:
-        print("Training '%d' restarted. Open http://%d/trainer/app?training=%d to monitor the training." %
+        print("Training '%s' restarted. Open http://%s/trainer/app?training=%s to monitor the training." %
               (job_id, aetros_backend.host, job_id))
 
-    aetros_backend.job_id = job_id
     job = aetros_backend.get_job()
 
-    if job == 'Job not found':
+    if job is None or job == 'Job not found':
         raise Exception('Training not found. Have you configured your token correctly?')
 
     if not isinstance(job, dict):
@@ -67,6 +64,7 @@ def start(job_id, dataset_id=None, server_id='local', insights=False):
     from KerasLogger import KerasLogger
     trainer = Trainer(aetros_backend, job_model, general_logger)
     keras_logger = KerasLogger(trainer, aetros_backend, job_model, general_logger)
+    keras_logger.insights_sample_path = insights_sample_path
     trainer.callbacks.append(keras_logger)
 
     sys.stdout = general_logger
@@ -74,7 +72,7 @@ def start(job_id, dataset_id=None, server_id='local', insights=False):
 
     job['running'] = True
 
-    monitoringThread = MonitoringThread(job, aetros_backend, trainer)
+    monitoringThread = MonitoringThread(aetros_backend, trainer)
     monitoringThread.daemon = True
     monitoringThread.start()
     network.collect_system_information(trainer)
@@ -86,10 +84,10 @@ def start(job_id, dataset_id=None, server_id='local', insights=False):
     signal.signal(signal.SIGINT, ctrlc)
 
     try:
-        print("Setup job")
+        print("Setup training")
         network.job_prepare(job)
 
-        print("Start job")
+        print("Start training")
         network.job_start(job_model, trainer, keras_logger, general_logger)
 
         job['running'] = False
@@ -112,7 +110,7 @@ def start(job_id, dataset_id=None, server_id='local', insights=False):
         monitoringThread.stop()
         job_model.sync_weights()
         aetros_backend.stop_syncer()
-        aetros_backend.post('job/stopped', json={'id': job_model.id, 'status': 'KILLED'})
+        aetros_backend.post('job/stopped', json={'id': job_model.id, 'status': 'EARLY STOP'})
         print("out.")
         sys.exit(1)
     except Exception as e:
@@ -128,4 +126,4 @@ def start(job_id, dataset_id=None, server_id='local', insights=False):
         aetros_backend.stop_syncer()
         aetros_backend.post('job/stopped', json={'id': job_model.id, 'status': 'CRASHED', 'error': e.message})
         print("out.")
-        sys.exit(1)
+        raise e
